/*
 * The contents of this file are subject to the JOnAS Public License Version
 * 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License on the JOnAS web site.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.
 * See the License for the specific terms governing rights and limitations
 * under
 * the License.
 *
 * The Original Code is JOnAS application server code released July 1999.
 *
 * The Initial Developer of the Original Code is Bull S.A.
 * The Original Code and portions created by Bull S.A. are
 *    Copyright (C) 1999,2001 Bull S.A. All Rights Reserved.
 *
 * Contributor(s):
 *
 * --------------------------------------------------------------------------
 * $Id: JQueueConnection.java,v 1.1 2001/12/21 10:53:48 jonas Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_jms;

import javax.jms.Connection;
import javax.jms.ConnectionConsumer;
import javax.jms.JMSException;
import javax.jms.Queue;
import javax.jms.QueueConnection;
import javax.jms.QueueSession;
import javax.jms.ServerSessionPool;
import javax.jms.XAQueueConnection;
import javax.jms.XAQueueConnectionFactory;

public class JQueueConnection extends JConnection implements QueueConnection {

    // The XAQueueConnection used in the MOM
    protected XAQueueConnection xaqc = null;

    protected XAQueueConnectionFactory xaqcf;

    /**
     * Constructor
     */
    public JQueueConnection(JConnectionFactory jcf, XAQueueConnectionFactory xaqcf, String user, String passwd) throws JMSException {
	super(jcf, user);
	this.xaqcf = xaqcf;

	// Create the underlaying XAQueueConnection
	xaqc = xaqcf.createXAQueueConnection(user, passwd);
	this.xac = (Connection) xaqc;
    }

    // -----------------------------------------------------------------------
    // QueueConnection implementation
    // -----------------------------------------------------------------------

    /**
     * Create a connection consumer for this connection 
     * @param queue - the queue to access
     * @param selector - only messages with properties matching the message
     * selector expression aredelivered
     * @param sessionPool - the server session pool to associate with this connection consumer.
     * @param maxMessages - the maximum number of messages that can be assigned
     * to a server session at one time.
     * @return the connection consumer.
     * @throws JMSException - if JMS Connection fails to create a a connection consumer
     * due to some internal error or invalid arguments for sessionPool and message selector.
     * @throws InvalidSelectorException - if the message selector is invalid.
     */
    public ConnectionConsumer createConnectionConsumer(Queue queue, 
						       String selector, 
						       ServerSessionPool pool, 
						       int maxmessages)	throws JMSException {
	TraceJms.debug( "JQueueConnection createConnectionConsumer");
	return xaqc.createConnectionConsumer(queue, selector, pool, maxmessages);
    }

    /**
     * Create a Queue Session
     * @param transacted - if true, the session is transacted.
     * @param acknowledgeMode - indicates whether the consumer or the client will 
     * acknowledge any messages it receives.
     * This parameter will be ignored if the session is transacted.
     * @return a newly created queue session.
     * @throws JMSException - if JMS Connection fails to create a session.
     */
    public QueueSession createQueueSession(boolean transacted, int acknowledgeMode) throws JMSException {
	TraceJms.debug( "JQueueConnection createQueueSession");
	return new JQueueSession(this, xaqc);
    }
}
