/*
 * The contents of this file are subject to the JOnAS Public License Version
 * 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License on the JOnAS web site.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.
 * See the License for the specific terms governing rights and limitations
 * under
 * the License.
 *
 * The Original Code is JOnAS application server code released July 1999.
 *
 * The Initial Developer of the Original Code is Bull S.A.
 * The Original Code and portions created by Bull S.A. are
 *    Copyright (C) 1999,2001 Bull S.A. All Rights Reserved.
 *
 * Contributor(s):
 *
 * --------------------------------------------------------------------------
 * $Id: JTopicConnection.java,v 1.1 2001/12/21 10:53:48 jonas Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_jms;

import javax.jms.Connection;
import javax.jms.ConnectionConsumer;
import javax.jms.JMSException;
import javax.jms.Topic;
import javax.jms.TopicConnection;
import javax.jms.TopicSession;
import javax.jms.ServerSessionPool;
import javax.jms.XATopicConnection;
import javax.jms.XATopicConnectionFactory;

public class JTopicConnection extends JConnection implements TopicConnection {

    // The XATopicConnection used in the MOM
    protected XATopicConnection xatc = null;

    protected XATopicConnectionFactory xatcf;

    /**
     * Constructor
     */
    public JTopicConnection(JConnectionFactory jcf, XATopicConnectionFactory xatcf, String user, String passwd) throws JMSException {
	super(jcf, user);
	this.xatcf = xatcf;

	// Create the underlaying XATopicConnection
	xatc = xatcf.createXATopicConnection(user, passwd);
	this.xac = (Connection) xatc;
    }

    // -----------------------------------------------------------------------
    // TopicConnection implementation
    // -----------------------------------------------------------------------

    /**
     * Create a TopicSession
     * @param transacted - if true, the session is transacted.
     * @param acknowledgeMode - indicates whether the consumer or the client will 
     * acknowledge any messages it receives.
     * This parameter will be ignored if the session is transacted.
     * @return a newly created topic session.
     * @throws JMSException - if JMS Connection fails to create a session.
     */
    public TopicSession createTopicSession(boolean transacted, int acknowledgeMode) throws JMSException {
	TraceJms.debug( "JTopicConnection createTopicSession");
	return new JTopicSession(this, xatc);
    }

    /**
     * @throws JMSException - if JMS Connection fails to create a ConnectionConsumer
     */
    public ConnectionConsumer createConnectionConsumer(Topic topic,
						       String messageSelector, 
						       ServerSessionPool sessionPool, 
						       int maxMessages) throws JMSException  {
	TraceJms.debug( "JTopicConnection: createConnectionConsumer");
	return xatc.createConnectionConsumer(topic, messageSelector, sessionPool, maxMessages);
    }

    /**
     * @throws JMSException - if JMS Connection fails to create a ConnectionConsumer
     */
    public ConnectionConsumer createDurableConnectionConsumer(Topic topic,
							      String subscriptionName, 
							      String messageSelector, 
							      ServerSessionPool sessionPool, 
							      int maxMessages) throws JMSException  {
	TraceJms.debug( "JTopicConnection: createDurableConnectionConsumer");
	return xatc.createDurableConnectionConsumer(topic, subscriptionName, messageSelector, sessionPool, maxMessages);
    }
}
