/*
 * The contents of this file are subject to the JOnAS Public License Version
 * 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License on the JOnAS web site.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.
 * See the License for the specific terms governing rights and limitations under
 * the License.
 *
 * The Original Code is JOnAS application server code released July 1999.
 *
 * The Initial Developer of the Original Code is Bull S.A.
 * The Original Code and portions created by Bull S.A. are
 *    Copyright (C) 1999,2001 Bull S.A. All Rights Reserved.
 *
 * Contributor(s): 
 *
 * --------------------------------------------------------------------------
 * $Id: JTopicConnectionFactory.java,v 1.1 2001/12/21 10:53:48 jonas Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_jms;

import javax.jms.JMSException;
import javax.jms.TopicConnection;
import javax.jms.TopicConnectionFactory;
import javax.jms.XATopicConnectionFactory;

/**
 * JTopicConnectionFactory wraps a XATopicConnectionFactory.
 */
public class JTopicConnectionFactory extends JConnectionFactory implements TopicConnectionFactory {
    
    private XATopicConnectionFactory xatcf;

    /**
     * Constructor.
     * The underlaying XATopicConnectionFactory is found in the JmsManager.
     */
    public JTopicConnectionFactory(String name) {
	super(name);
	xatcf = jms.getXATopicConnectionFactory();
    }

    // -----------------------------------------------------------------------
    // TopicConnectionFactory implementation
    // -----------------------------------------------------------------------

    /**
     * Create a topic connection with default user identity.
     * @return a newly created topic connection.
     * @throws JMSException - if JMS Provider fails to create a Topic 
     * Connection due to some internal error.
     * @throws JMSSecurityException - if client authentication fails due to 
     * invalid user name or password.
     */
    public TopicConnection createTopicConnection() throws JMSException {
	return createTopicConnection("jonas", "jonas");
    }

    /**
     * Create a topic connection with specified user identity. 
     * The connection is created in stopped mode. No messages will
     * be delivered until Connection.start method is explicitly called.
     * @param userName - the caller's user name
     * @param password - the caller's password
     * @throws JMSException - if JMS Provider fails to create Topic Connection 
     * due to some internal error. required resources for a Topic Connection.
     * @throws JMSSecurityException - if client authentication fails due to 
     * invalid user name or password.
     */
    public TopicConnection createTopicConnection(String userName, String password) throws JMSException {
	TraceJms.debug( "JTopicConnectionFactory: createTopicConnection");
	// Try to reuse a connection from the pool.
	// Create a new one if no connection available.
	JTopicConnection tc = (JTopicConnection) getJConnection(userName);
	if (tc == null) {
	    tc = new JTopicConnection(this, xatcf, userName, password);
	}
	return (TopicConnection) tc;
    }

} 
