/*
 * The contents of this file are subject to the JOnAS Public License Version 
 * 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License on the JOnAS web site.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.
 * See the License for the specific terms governing rights and limitations under 
 * the License.
 *
 * The Original Code is JOnAS application server code released July 1999.
 *
 * The Initial Developer of the Original Code is Bull S.A.
 * The Original Code and portions created by Bull S.A. are
 *    Copyright (C) 2001 Bull S.A. All Rights Reserved.
 *
 * Contributor(s): ______________________________________.
 *
 * --------------------------------------------------------------------------
 * $Id: JmsAdministration.java,v 1.2 2001/12/21 10:53:49 jonas Exp $
 * --------------------------------------------------------------------------
 */


package org.objectweb.jonas_jms.api;

import javax.jms.Queue;
import javax.jms.QueueConnectionFactory;
import javax.jms.XAQueueConnectionFactory;
import javax.jms.Topic;
import javax.jms.TopicConnectionFactory;
import javax.jms.XATopicConnectionFactory;


/**
 * JMS Administration interface.
 * must be implemented for each jms provider
 * JOnAS uses this interface to access the JMS provider.
 */
public interface JmsAdministration {

    /**
     * Jms Administrator is created with newInstance().
     * initialization is done later with this method.
     * The MOM will be started if collocated.
     * This method should create an XATopicConnectionFactory and
     * an XAQueueConnectionFactory
     * @param boolean true for if the MOM in run in the current JVM
     * @param String url connexion that must be used.
     */
    public void start(boolean collocated, String url) throws Exception;

    /**
     * Stop the Jms Administrator
     */
    public void stop();

    /**
     * Get the XATopicConnectionFactory
     */
    public XATopicConnectionFactory getXATopicConnectionFactory();

    /**
     * Get the XAQueueConnectionFactory
     */
    public XAQueueConnectionFactory getXAQueueConnectionFactory();

    /**
     * Create a Topic
     */
    public Topic createTopic() throws Exception;

    /**
     * Create a Queue
     */
    public Queue createQueue() throws Exception;
}
