/*
 * The contents of this file are subject to the JOnAS Public License Version 
 * 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License on the JOnAS web site.
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.
 * See the License for the specific terms governing rights and limitations under 
 * the License.
 *
 * The Original Code is JOnAS application server code released July 1999.
 *
 * The Initial Developer of the Original Code is Bull S.A.
 * The Original Code and portions created by Bull S.A. are
 *    Copyright (C) 2001 Bull S.A. All Rights Reserved.
 *
 * Contributor(s):
 *
 * --------------------------------------------------------------------------
 * $Id: JmsManager.java,v 1.2 2001/12/21 10:53:49 jonas Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_jms.api;

import java.util.Enumeration;
import javax.jms.Queue;
import javax.jms.QueueConnectionFactory;
import javax.jms.XAQueueConnectionFactory;
import javax.jms.Topic;
import javax.jms.TopicConnectionFactory;
import javax.jms.XATopicConnectionFactory;
import javax.transaction.TransactionManager;

/**
 * JMS Manager interface.
 * Implemented by the jms module (jonas_jms/JmsManagerImpl)
 * This interface allows other jonas module to be independant 
 * of jonas_jms implementation.
 */
public interface JmsManager {

    /**
     * Initialisation of JmsManager
     *
     * @param class cl class implementing administration process
     * @param boolean true for launching the MOM in the same JVM
     * @param String connexion url to the MOM (in case of remote mode)
     * @param TransactionManager tm
     * @exception  Exception must be thrown if the MOM is unreachable
     */
    public void init(Class cl, boolean collocated, String url, TransactionManager tm) throws Exception;

   /**
     * Terminate the administering process
     */
    public void stop() throws Exception;

    /**
     * Create a Queue and bind it in the registry
     */
    public Queue createQueue(String name) throws Exception;

    /**
     *  Get Queue (creates it if not exist)
     */
    public Queue getQueue(String name) throws Exception;

    /**
     *  Get Queue Names
     */
    public Enumeration getQueuesNames();

    /**
     * Create a Topic and bind it in the registry
     */
    public Topic createTopic(String name) throws Exception;

    /**
     *  Get Topic (creates it if not exist)
     */
    public Topic getTopic(String name) throws Exception;

    /**
     *  Get Topic Names
     */
    public Enumeration getTopicsNames();

    /**
     *  Get the unique TopicConnectionFactory
     */
    public TopicConnectionFactory getTopicConnectionFactory();

    /**
     *  Get the unique XATopicConnectionFactory
     */
    public XATopicConnectionFactory getXATopicConnectionFactory();

    /**
     *  Get the unique QueueConnectionFactory
     */
    public QueueConnectionFactory getQueueConnectionFactory();

    /**
     *  Get the unique XAQueueConnectionFactory
     */
    public XAQueueConnectionFactory getXAQueueConnectionFactory();
}

